@@ -33,7 +33,7 @@ int main(int argc, char** argv)
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain("muon-exporter");
     KAboutData about("muonexporter", i18n("Muon Exporter"), version, i18n(description),
-                     KAboutLicense::GPL, i18n("©2013 Aleix Pol Gonzalez"), QString(), 0);
+                     KAboutLicense::GPL, i18n("©2013 Aleix Pol Gonzalez"), QString(), nullptr);
     about.addAuthor(i18n("Jonathan Thomas"), QString(), "echidnaman@kubuntu.org");
     about.addAuthor(i18n("Aleix Pol Gonzalez"), QString(), "aleixpol@blue-systems.com");
     about.setProductName("muon/exporter");
@@ -54,7 +54,7 @@ int main(int argc, char** argv)
         if(parser.positionalArguments().count() != 1) {
             parser.showHelp(1);
         }
-        exp.setExportPath(QUrl::fromUserInput(parser.positionalArguments().first()/*, QString(), QUrl::AssumeLocalFile*/));
+        exp.setExportPath(QUrl::fromUserInput(parser.positionalArguments().first(), QString(), QUrl::AssumeLocalFile));
     }
 
     QObject::connect(&exp, SIGNAL(exportDone()), &app, SLOT(quit()));
