@@ -80,7 +80,7 @@ Application::Application(QApt::Package* package, QApt::Backend* backend)
     
     QString arch = m_package->architecture();
     if (arch != m_backend->nativeArchitecture() && arch != QLatin1String("all"))
-        m_packageName.append(QByteArray(":") + m_package->architecture().toLatin1());
+        m_packageName.append(QLatin1Char(':') + m_package->architecture().toLatin1());
 
     if (m_package->origin() == QLatin1String("LP-PPA-app-review-board")) {
         if (!m_package->controlField(QLatin1String("Appname")).isEmpty()) {
@@ -257,12 +257,12 @@ QVector<QPair<QString, QString> > Application::locateApplication(const QString &
 
 QStringList Application::categories()
 {
-    QStringList categories = QString(getField("Categories")).split(',', QString::SkipEmptyParts);
+    QStringList categories = QString(getField("Categories")).split(';', QString::SkipEmptyParts);
 
     if (categories.isEmpty()) {
         // extras.ubuntu.com packages can have this field
         if (m_isExtrasApp)
-            categories += package()->controlField(QLatin1String("Category"));
+            categories = package()->controlField(QLatin1String("Category")).split(';');
     }
     return categories;
 }
