@@ -39,6 +39,7 @@
 #include <KIO/Job>
 #include <KActionCollection>
 #include <KIconLoader>
+#include <KXmlGuiWindow>
 
 // QApt/DebconfKDE includes
 #include <QApt/Backend>
@@ -57,7 +58,6 @@
 #include "Transaction/Transaction.h"
 #include "Transaction/TransactionModel.h"
 #include "ApplicationUpdates.h"
-#include "MuonMainWindow.h"
 #include <resources/SourcesModel.h>
 #include <MuonDataSources.h>
 
@@ -146,7 +146,7 @@ void ApplicationBackend::setApplications()
     connect(job, SIGNAL(finished(KJob*)), SLOT(initAvailablePackages(KJob*)));
 
     if (m_aptify)
-        m_aptify->setCanExit(true);
+        QAptActions::self()->setCanExit(true);
     setFetching(false);
 }
 
@@ -158,7 +158,7 @@ void ApplicationBackend::reload()
     }
     setFetching(true);
     if (m_aptify)
-        m_aptify->setCanExit(false);
+        QAptActions::self()->setCanExit(false);
     foreach(Application* app, m_appList)
         app->clearPackage();
     qDeleteAll(m_transQueue);
@@ -172,7 +172,7 @@ void ApplicationBackend::reload()
         app->package();
 
     if (m_aptify)
-        m_aptify->setCanExit(true);
+        QAptActions::self()->setCanExit(true);
     setFetching(false);
 }
 
@@ -526,7 +526,7 @@ AbstractBackendUpdater* ApplicationBackend::backendUpdater() const
     return m_backendUpdater;
 }
 
-void ApplicationBackend::integrateMainWindow(MuonMainWindow* w)
+void ApplicationBackend::integrateMainWindow(KXmlGuiWindow* w)
 {
     m_aptify = w;
     QAptActions* apt = QAptActions::self();
@@ -539,9 +539,9 @@ void ApplicationBackend::integrateMainWindow(MuonMainWindow* w)
     updateAction->setIcon(QIcon::fromTheme("system-software-update"));
     updateAction->setText(i18nc("@action Checks the Internet for updates", "Check for Updates"));
     updateAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_R));
-    updateAction->setEnabled(w->isConnected());
+    updateAction->setEnabled(apt->isConnected());
     connect(updateAction, SIGNAL(triggered()), SLOT(checkForUpdates()));
-    connect(w, SIGNAL(shouldConnect(bool)), updateAction, SLOT(setEnabled(bool)));
+    connect(apt, SIGNAL(shouldConnect(bool)), updateAction, SLOT(setEnabled(bool)));
 }
 
 QWidget* ApplicationBackend::mainWindow() const
@@ -553,7 +553,7 @@ void ApplicationBackend::initBackend()
 {
     setFetching(true);
     if (m_aptify) {
-        m_aptify->setCanExit(false);
+        QAptActions::self()->setCanExit(false);
         QAptActions::self()->setReloadWhenEditorFinished(true);
     }
 
